# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator

class BusinessTransitionRequest(BaseModel):
    """
    BusinessTransitionRequest
    """
    idempotent_hash: Optional[StrictStr] = Field(None, alias="idempotentHash")
    token: Optional[StrictStr] = None
    status: StrictStr = ...
    reason_code: StrictStr = ...
    reason: Optional[StrictStr] = None
    channel: StrictStr = ...
    business_token: StrictStr = ...
    __properties = ["idempotentHash", "token", "status", "reason_code", "reason", "channel", "business_token"]

    @validator('status')
    def status_validate_enum(cls, v):
        if v not in ('UNVERIFIED', 'LIMITED', 'ACTIVE', 'SUSPENDED', 'CLOSED'):
            raise ValueError("must be one of enum values ('UNVERIFIED', 'LIMITED', 'ACTIVE', 'SUSPENDED', 'CLOSED')")
        return v

    @validator('reason_code')
    def reason_code_validate_enum(cls, v):
        if v not in ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31'):
            raise ValueError("must be one of enum values ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31')")
        return v

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v not in ('API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM'):
            raise ValueError("must be one of enum values ('API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessTransitionRequest:
        """Create an instance of BusinessTransitionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessTransitionRequest:
        """Create an instance of BusinessTransitionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BusinessTransitionRequest.parse_obj(obj)

        _obj = BusinessTransitionRequest.parse_obj({
            "idempotent_hash": obj.get("idempotentHash"),
            "token": obj.get("token"),
            "status": obj.get("status"),
            "reason_code": obj.get("reason_code"),
            "reason": obj.get("reason"),
            "channel": obj.get("channel"),
            "business_token": obj.get("business_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, StrictStr
from marqeta_client.models.internal_digital_wallet_token import InternalDigitalWalletToken
from marqeta_client.models.internal_transaction_data_model import InternalTransactionDataModel

class CardValidationRequest(BaseModel):
    """
    CardValidationRequest
    """
    hash: StrictStr = ...
    expiration_date: Optional[StrictStr] = None
    config: Optional[Dict[str, StrictStr]] = None
    digital_wallet: Optional[InternalDigitalWalletToken] = None
    transaction: Optional[InternalTransactionDataModel] = None
    __properties = ["hash", "expiration_date", "config", "digital_wallet", "transaction"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardValidationRequest:
        """Create an instance of CardValidationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of digital_wallet
        if self.digital_wallet:
            _dict['digital_wallet'] = self.digital_wallet.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardValidationRequest:
        """Create an instance of CardValidationRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardValidationRequest.parse_obj(obj)

        _obj = CardValidationRequest.parse_obj({
            "hash": obj.get("hash"),
            "expiration_date": obj.get("expiration_date"),
            "config": obj.get("config"),
            "digital_wallet": InternalDigitalWalletToken.from_dict(obj.get("digital_wallet")) if obj.get("digital_wallet") is not None else None,
            "transaction": InternalTransactionDataModel.from_dict(obj.get("transaction")) if obj.get("transaction") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.application import Application

class ClientAccessTokenResponse(BaseModel):
    """
    ClientAccessTokenResponse
    """
    application: Optional[Application] = None
    created: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    expires: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    token: Optional[StrictStr] = None
    card_token: Optional[StrictStr] = None
    __properties = ["application", "created", "expires", "token", "card_token"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ClientAccessTokenResponse:
        """Create an instance of ClientAccessTokenResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of application
        if self.application:
            _dict['application'] = self.application.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ClientAccessTokenResponse:
        """Create an instance of ClientAccessTokenResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ClientAccessTokenResponse.parse_obj(obj)

        _obj = ClientAccessTokenResponse.parse_obj({
            "application": Application.from_dict(obj.get("application")) if obj.get("application") is not None else None,
            "created": obj.get("created"),
            "expires": obj.get("expires"),
            "token": obj.get("token"),
            "card_token": obj.get("card_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr, conlist, constr, validator

class CalculationSchedule(BaseModel):
    """
    CalculationSchedule
    """
    token: constr(strict=True, max_length=36, min_length=1) = ...
    value_type: Optional[StrictStr] = 'PERCENT'
    name: constr(strict=True, max_length=32, min_length=1) = ...
    steps: conlist(Union[StrictFloat, StrictInt]) = ...
    step_values: conlist(Union[StrictFloat, StrictInt]) = ...
    __properties = ["token", "value_type", "name", "steps", "step_values"]

    @validator('value_type')
    def value_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('AMOUNT', 'PERCENT'):
            raise ValueError("must be one of enum values ('AMOUNT', 'PERCENT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CalculationSchedule:
        """Create an instance of CalculationSchedule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CalculationSchedule:
        """Create an instance of CalculationSchedule from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CalculationSchedule.parse_obj(obj)

        _obj = CalculationSchedule.parse_obj({
            "token": obj.get("token"),
            "value_type": obj.get("value_type") if obj.get("value_type") is not None else 'PERCENT',
            "name": obj.get("name"),
            "steps": obj.get("steps"),
            "step_values": obj.get("step_values")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr

from typing import Optional

from marqeta_client.models.business_card_holder_list_response import BusinessCardHolderListResponse
from marqeta_client.models.business_card_holder_response import BusinessCardHolderResponse
from marqeta_client.models.business_card_holder_update import BusinessCardHolderUpdate
from marqeta_client.models.business_cardholder import BusinessCardholder
from marqeta_client.models.business_user_card_holder_list_response import BusinessUserCardHolderListResponse
from marqeta_client.models.card_holder_note_list_response import CardHolderNoteListResponse
from marqeta_client.models.cardholder_note_request_model import CardholderNoteRequestModel
from marqeta_client.models.cardholder_note_response_model import CardholderNoteResponseModel
from marqeta_client.models.cardholder_note_update_request_model import CardholderNoteUpdateRequestModel
from marqeta_client.models.dda_request import DDARequest
from marqeta_client.models.ssn_response_model import SsnResponseModel

from marqeta_client.api_client import ApiClient
from marqeta_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class BusinessesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_businesses(self, count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, business_name_dba : Annotated[Optional[StrictStr], Field(description="Business name DBA")] = None, business_name_legal : Annotated[Optional[StrictStr], Field(description="Business name legal")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> BusinessCardHolderListResponse:  # noqa: E501
        """Lists all businesses  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses(count, start_index, business_name_dba, business_name_legal, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param business_name_dba: Business name DBA
        :type business_name_dba: str
        :param business_name_legal: Business name legal
        :type business_name_legal: str
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessCardHolderListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_businesses_with_http_info(count, start_index, business_name_dba, business_name_legal, search_type, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_businesses_with_http_info(self, count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, business_name_dba : Annotated[Optional[StrictStr], Field(description="Business name DBA")] = None, business_name_legal : Annotated[Optional[StrictStr], Field(description="Business name legal")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists all businesses  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_with_http_info(count, start_index, business_name_dba, business_name_legal, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param business_name_dba: Business name DBA
        :type business_name_dba: str
        :param business_name_legal: Business name legal
        :type business_name_legal: str
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessCardHolderListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'count',
            'start_index',
            'business_name_dba',
            'business_name_legal',
            'search_type',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_businesses" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('business_name_dba') is not None:  # noqa: E501
            _query_params.append(('business_name_dba', _params['business_name_dba']))

        if _params.get('business_name_legal') is not None:  # noqa: E501
            _query_params.append(('business_name_legal', _params['business_name_legal']))

        if _params.get('search_type') is not None:  # noqa: E501
            _query_params.append(('search_type', _params['search_type']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "BusinessCardHolderListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_businesses_parenttoken_children(self, parent_token : Annotated[StrictStr, Field(..., description="Token of parent business")], count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> BusinessUserCardHolderListResponse:  # noqa: E501
        """Lists all children of a parent business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_parenttoken_children(parent_token, count, start_index, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param parent_token: Token of parent business (required)
        :type parent_token: str
        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessUserCardHolderListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_businesses_parenttoken_children_with_http_info(parent_token, count, start_index, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_businesses_parenttoken_children_with_http_info(self, parent_token : Annotated[StrictStr, Field(..., description="Token of parent business")], count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists all children of a parent business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_parenttoken_children_with_http_info(parent_token, count, start_index, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param parent_token: Token of parent business (required)
        :type parent_token: str
        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessUserCardHolderListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'parent_token',
            'count',
            'start_index',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_businesses_parenttoken_children" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['parent_token']:
            _path_params['parent_token'] = _params['parent_token']


        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "BusinessUserCardHolderListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{parent_token}/children', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_businesses_token(self, token : Annotated[StrictStr, Field(..., description="Business token")], fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, **kwargs) -> BusinessCardHolderResponse:  # noqa: E501
        """Returns a specific business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_token(token, fields, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessCardHolderResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_businesses_token_with_http_info(token, fields, **kwargs)  # noqa: E501

    @validate_arguments
    def get_businesses_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Business token")], fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, **kwargs):  # noqa: E501
        """Returns a specific business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_token_with_http_info(token, fields, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessCardHolderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'fields'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_businesses_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "BusinessCardHolderResponse",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_businesses_token_notes(self, token : Annotated[StrictStr, Field(..., description="Business token")], start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, count : Annotated[Optional[StrictInt], Field(description="Number of notes to retrieve")] = None, created_by : Annotated[Optional[StrictStr], Field(description="Created by")] = None, created_by_user_role : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of created by user roles")] = None, include_private : Annotated[Optional[StrictBool], Field(description="Include private notes and private fields in note response")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> CardHolderNoteListResponse:  # noqa: E501
        """Lists business notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_token_notes(token, start_index, count, created_by, created_by_user_role, include_private, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param start_index: Start index
        :type start_index: int
        :param count: Number of notes to retrieve
        :type count: int
        :param created_by: Created by
        :type created_by: str
        :param created_by_user_role: Comma-delimited list of created by user roles
        :type created_by_user_role: str
        :param include_private: Include private notes and private fields in note response
        :type include_private: bool
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardHolderNoteListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_businesses_token_notes_with_http_info(token, start_index, count, created_by, created_by_user_role, include_private, search_type, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_businesses_token_notes_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Business token")], start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, count : Annotated[Optional[StrictInt], Field(description="Number of notes to retrieve")] = None, created_by : Annotated[Optional[StrictStr], Field(description="Created by")] = None, created_by_user_role : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of created by user roles")] = None, include_private : Annotated[Optional[StrictBool], Field(description="Include private notes and private fields in note response")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists business notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_token_notes_with_http_info(token, start_index, count, created_by, created_by_user_role, include_private, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param start_index: Start index
        :type start_index: int
        :param count: Number of notes to retrieve
        :type count: int
        :param created_by: Created by
        :type created_by: str
        :param created_by_user_role: Comma-delimited list of created by user roles
        :type created_by_user_role: str
        :param include_private: Include private notes and private fields in note response
        :type include_private: bool
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardHolderNoteListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'start_index',
            'count',
            'created_by',
            'created_by_user_role',
            'include_private',
            'search_type',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_businesses_token_notes" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('created_by') is not None:  # noqa: E501
            _query_params.append(('created_by', _params['created_by']))

        if _params.get('created_by_user_role') is not None:  # noqa: E501
            _query_params.append(('created_by_user_role', _params['created_by_user_role']))

        if _params.get('include_private') is not None:  # noqa: E501
            _query_params.append(('include_private', _params['include_private']))

        if _params.get('search_type') is not None:  # noqa: E501
            _query_params.append(('search_type', _params['search_type']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "CardHolderNoteListResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{token}/notes', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_businesses_token_ssn(self, token : Annotated[StrictStr, Field(..., description="Business token")], full_ssn : Optional[StrictBool] = None, **kwargs) -> SsnResponseModel:  # noqa: E501
        """Returns a specific business proprietor's SSN  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_token_ssn(token, full_ssn, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param full_ssn:
        :type full_ssn: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SsnResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.get_businesses_token_ssn_with_http_info(token, full_ssn, **kwargs)  # noqa: E501

    @validate_arguments
    def get_businesses_token_ssn_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Business token")], full_ssn : Optional[StrictBool] = None, **kwargs):  # noqa: E501
        """Returns a specific business proprietor's SSN  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_businesses_token_ssn_with_http_info(token, full_ssn, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param full_ssn:
        :type full_ssn: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SsnResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'full_ssn'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_businesses_token_ssn" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('full_ssn') is not None:  # noqa: E501
            _query_params.append(('full_ssn', _params['full_ssn']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "SsnResponseModel",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{token}/ssn', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_businesses(self, body : Optional[BusinessCardholder] = None, **kwargs) -> BusinessCardHolderResponse:  # noqa: E501
        """Creates a business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_businesses(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: BusinessCardholder
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessCardHolderResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.post_businesses_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_businesses_with_http_info(self, body : Optional[BusinessCardholder] = None, **kwargs):  # noqa: E501
        """Creates a business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_businesses_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: BusinessCardholder
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessCardHolderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_businesses" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "BusinessCardHolderResponse",
            '400': None,
            '409': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_businesses_lookup(self, body : Optional[DDARequest] = None, **kwargs) -> BusinessCardholder:  # noqa: E501
        """Returns a specific business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_businesses_lookup(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: DDARequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessCardholder
        """
        kwargs['_return_http_data_only'] = True
        return self.post_businesses_lookup_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_businesses_lookup_with_http_info(self, body : Optional[DDARequest] = None, **kwargs):  # noqa: E501
        """Returns a specific business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_businesses_lookup_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: DDARequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessCardholder, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_businesses_lookup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "BusinessCardholder",
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/lookup', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_businesses_token_notes(self, token : Annotated[StrictStr, Field(..., description="Business token")], body : Optional[CardholderNoteRequestModel] = None, **kwargs) -> CardholderNoteResponseModel:  # noqa: E501
        """Creates a note for a business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_businesses_token_notes(token, body, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param body:
        :type body: CardholderNoteRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardholderNoteResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.post_businesses_token_notes_with_http_info(token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_businesses_token_notes_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Business token")], body : Optional[CardholderNoteRequestModel] = None, **kwargs):  # noqa: E501
        """Creates a note for a business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_businesses_token_notes_with_http_info(token, body, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param body:
        :type body: CardholderNoteRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardholderNoteResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_businesses_token_notes" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "CardholderNoteResponseModel",
            '400': None,
            '401': None,
            '403': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{token}/notes', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def put_businesses_token(self, token : Annotated[StrictStr, Field(..., description="Business token")], body : Annotated[BusinessCardHolderUpdate, Field(..., description="Business object")], **kwargs) -> BusinessCardholder:  # noqa: E501
        """Updates a specific business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_businesses_token(token, body, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param body: Business object (required)
        :type body: BusinessCardHolderUpdate
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessCardholder
        """
        kwargs['_return_http_data_only'] = True
        return self.put_businesses_token_with_http_info(token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def put_businesses_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Business token")], body : Annotated[BusinessCardHolderUpdate, Field(..., description="Business object")], **kwargs):  # noqa: E501
        """Updates a specific business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_businesses_token_with_http_info(token, body, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param body: Business object (required)
        :type body: BusinessCardHolderUpdate
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessCardholder, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_businesses_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "BusinessCardholder",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{token}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def put_businesses_token_notes_notestoken(self, token : Annotated[StrictStr, Field(..., description="Business token")], notes_token : Annotated[StrictStr, Field(..., description="Notes token")], body : Optional[CardholderNoteUpdateRequestModel] = None, **kwargs) -> CardholderNoteResponseModel:  # noqa: E501
        """Updates a specific note for a business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_businesses_token_notes_notestoken(token, notes_token, body, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param notes_token: Notes token (required)
        :type notes_token: str
        :param body:
        :type body: CardholderNoteUpdateRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardholderNoteResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.put_businesses_token_notes_notestoken_with_http_info(token, notes_token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def put_businesses_token_notes_notestoken_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Business token")], notes_token : Annotated[StrictStr, Field(..., description="Notes token")], body : Optional[CardholderNoteUpdateRequestModel] = None, **kwargs):  # noqa: E501
        """Updates a specific note for a business  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_businesses_token_notes_notestoken_with_http_info(token, notes_token, body, async_req=True)
        >>> result = thread.get()

        :param token: Business token (required)
        :type token: str
        :param notes_token: Notes token (required)
        :type notes_token: str
        :param body:
        :type body: CardholderNoteUpdateRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardholderNoteResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'notes_token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_businesses_token_notes_notestoken" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']

        if _params['notes_token']:
            _path_params['notes_token'] = _params['notes_token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "CardholderNoteResponseModel",
            '400': None,
            '401': None,
            '403': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/businesses/{token}/notes/{notes_token}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, validator
from marqeta_client.models.airline import Airline
from marqeta_client.models.transit import Transit

class TransactionMetadata(BaseModel):
    """
    TransactionMetadata
    """
    transaction_category: Optional[StrictStr] = None
    payment_channel: Optional[StrictStr] = None
    cross_border_transaction: Optional[StrictBool] = False
    authorization_life_cycle: Optional[StrictInt] = None
    is_lodging_auto_rental: Optional[StrictBool] = False
    is_deferred_authorization: Optional[StrictBool] = None
    lodging_auto_rental_start_date: Optional[datetime] = None
    transit: Optional[Transit] = None
    airline: Optional[Airline] = None
    moto_indicator: Optional[StrictStr] = None
    one_leg_out: Optional[StrictBool] = None
    __properties = ["transaction_category", "payment_channel", "cross_border_transaction", "authorization_life_cycle", "is_lodging_auto_rental", "is_deferred_authorization", "lodging_auto_rental_start_date", "transit", "airline", "moto_indicator", "one_leg_out"]

    @validator('transaction_category')
    def transaction_category_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('RETAIL_SALE', 'BILL_PAY', 'HOTEL', 'HEALTH_CARE', 'RESTAURANT', 'AUTO_RENTAL', 'AIRLINE', 'PAYMENT', 'HOSPITALIZATION_COLLEGE', 'PHONE_MAIL_ECOMMERCE', 'ATM', 'TRANSIT'):
            raise ValueError("must be one of enum values ('RETAIL_SALE', 'BILL_PAY', 'HOTEL', 'HEALTH_CARE', 'RESTAURANT', 'AUTO_RENTAL', 'AIRLINE', 'PAYMENT', 'HOSPITALIZATION_COLLEGE', 'PHONE_MAIL_ECOMMERCE', 'ATM', 'TRANSIT')")
        return v

    @validator('payment_channel')
    def payment_channel_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('OTHER', 'ATM', 'ECOMMERCE', 'MAIL', 'PHONE', 'MOTO'):
            raise ValueError("must be one of enum values ('OTHER', 'ATM', 'ECOMMERCE', 'MAIL', 'PHONE', 'MOTO')")
        return v

    @validator('moto_indicator')
    def moto_indicator_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNKNOWN', 'MANUAL', 'RECURRING', 'INSTALLMENT', 'OTHERS'):
            raise ValueError("must be one of enum values ('UNKNOWN', 'MANUAL', 'RECURRING', 'INSTALLMENT', 'OTHERS')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransactionMetadata:
        """Create an instance of TransactionMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of transit
        if self.transit:
            _dict['transit'] = self.transit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of airline
        if self.airline:
            _dict['airline'] = self.airline.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransactionMetadata:
        """Create an instance of TransactionMetadata from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TransactionMetadata.parse_obj(obj)

        _obj = TransactionMetadata.parse_obj({
            "transaction_category": obj.get("transaction_category"),
            "payment_channel": obj.get("payment_channel"),
            "cross_border_transaction": obj.get("cross_border_transaction") if obj.get("cross_border_transaction") is not None else False,
            "authorization_life_cycle": obj.get("authorization_life_cycle"),
            "is_lodging_auto_rental": obj.get("is_lodging_auto_rental") if obj.get("is_lodging_auto_rental") is not None else False,
            "is_deferred_authorization": obj.get("is_deferred_authorization"),
            "lodging_auto_rental_start_date": obj.get("lodging_auto_rental_start_date"),
            "transit": Transit.from_dict(obj.get("transit")) if obj.get("transit") is not None else None,
            "airline": Airline.from_dict(obj.get("airline")) if obj.get("airline") is not None else None,
            "moto_indicator": obj.get("moto_indicator"),
            "one_leg_out": obj.get("one_leg_out")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictBool, StrictStr
from marqeta_client.models.funding_source_model import FundingSourceModel

class ChargebackFundingSourceModel(FundingSourceModel):
    """
    ChargebackFundingSourceModel
    """
    name: StrictStr = ...
    credit: StrictBool = ...
    __properties = ["token", "active", "is_default_account", "created_time", "last_modified_time", "type", "name", "credit"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChargebackFundingSourceModel:
        """Create an instance of ChargebackFundingSourceModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChargebackFundingSourceModel:
        """Create an instance of ChargebackFundingSourceModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ChargebackFundingSourceModel.parse_obj(obj)

        _obj = ChargebackFundingSourceModel.parse_obj({
            "token": obj.get("token"),
            "active": obj.get("active") if obj.get("active") is not None else False,
            "is_default_account": obj.get("is_default_account") if obj.get("is_default_account") is not None else False,
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "type": obj.get("type"),
            "name": obj.get("name"),
            "credit": obj.get("credit")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr

class AutoCommandoModeProgramFundingSourceResponse(BaseModel):
    """
    AutoCommandoModeProgramFundingSourceResponse
    """
    name: constr(strict=True, max_length=50, min_length=1) = ...
    active: Optional[StrictBool] = None
    token: constr(strict=True, max_length=36, min_length=1) = ...
    created_time: datetime = ...
    last_modified_time: datetime = ...
    account: StrictStr = ...
    __properties = ["name", "active", "token", "created_time", "last_modified_time", "account"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AutoCommandoModeProgramFundingSourceResponse:
        """Create an instance of AutoCommandoModeProgramFundingSourceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AutoCommandoModeProgramFundingSourceResponse:
        """Create an instance of AutoCommandoModeProgramFundingSourceResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AutoCommandoModeProgramFundingSourceResponse.parse_obj(obj)

        _obj = AutoCommandoModeProgramFundingSourceResponse.parse_obj({
            "name": obj.get("name"),
            "active": obj.get("active"),
            "token": obj.get("token"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "account": obj.get("account")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, constr

class PushToCardRequest(BaseModel):
    """
    PushToCardRequest
    """
    address_1: constr(strict=True, max_length=255, min_length=1) = ...
    address_2: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    city: constr(strict=True, max_length=40, min_length=1) = ...
    state: constr(strict=True, max_length=2, min_length=1) = ...
    postal_code: constr(strict=True, max_length=10, min_length=1) = ...
    country: StrictStr = ...
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    user_token: constr(strict=True, max_length=36, min_length=1) = ...
    name_on_card: constr(strict=True, max_length=50, min_length=1) = ...
    pan: constr(strict=True, max_length=19, min_length=14) = ...
    cvv: StrictStr = ...
    exp_date: StrictStr = ...
    __properties = ["address_1", "address_2", "city", "state", "postal_code", "country", "token", "user_token", "name_on_card", "pan", "cvv", "exp_date"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PushToCardRequest:
        """Create an instance of PushToCardRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PushToCardRequest:
        """Create an instance of PushToCardRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PushToCardRequest.parse_obj(obj)

        _obj = PushToCardRequest.parse_obj({
            "address_1": obj.get("address_1"),
            "address_2": obj.get("address_2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "postal_code": obj.get("postal_code"),
            "country": obj.get("country"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "name_on_card": obj.get("name_on_card"),
            "pan": obj.get("pan"),
            "cvv": obj.get("cvv"),
            "exp_date": obj.get("exp_date")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, constr, validator
from marqeta_client.models.address_response_model import AddressResponseModel

class BusinessIncorporationResponse(BaseModel):
    """
    BusinessIncorporationResponse
    """
    is_public: Optional[StrictBool] = False
    stock_symbol: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    state_of_incorporation: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    name_registered_under: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    address_registered_under: Optional[AddressResponseModel] = None
    incorporation_type: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    __properties = ["is_public", "stock_symbol", "state_of_incorporation", "name_registered_under", "address_registered_under", "incorporation_type"]

    @validator('incorporation_type')
    def incorporation_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('LLC', 'CORPORATION', 'SOLE_PROPRIETORSHIP', 'PARTNERSHIP', 'OTHER'):
            raise ValueError("must be one of enum values ('LLC', 'CORPORATION', 'SOLE_PROPRIETORSHIP', 'PARTNERSHIP', 'OTHER')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessIncorporationResponse:
        """Create an instance of BusinessIncorporationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address_registered_under
        if self.address_registered_under:
            _dict['address_registered_under'] = self.address_registered_under.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessIncorporationResponse:
        """Create an instance of BusinessIncorporationResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BusinessIncorporationResponse.parse_obj(obj)

        _obj = BusinessIncorporationResponse.parse_obj({
            "is_public": obj.get("is_public") if obj.get("is_public") is not None else False,
            "stock_symbol": obj.get("stock_symbol"),
            "state_of_incorporation": obj.get("state_of_incorporation"),
            "name_registered_under": obj.get("name_registered_under"),
            "address_registered_under": AddressResponseModel.from_dict(obj.get("address_registered_under")) if obj.get("address_registered_under") is not None else None,
            "incorporation_type": obj.get("incorporation_type")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from marqeta_client.models.images_card import ImagesCard
from marqeta_client.models.images_carrier import ImagesCarrier
from marqeta_client.models.images_carrier_return_window import ImagesCarrierReturnWindow
from marqeta_client.models.images_signature import ImagesSignature

class Images(BaseModel):
    """
    Images
    """
    card: Optional[ImagesCard] = None
    carrier: Optional[ImagesCarrier] = None
    signature: Optional[ImagesSignature] = None
    carrier_return_window: Optional[ImagesCarrierReturnWindow] = None
    __properties = ["card", "carrier", "signature", "carrier_return_window"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Images:
        """Create an instance of Images from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of carrier
        if self.carrier:
            _dict['carrier'] = self.carrier.to_dict()
        # override the default output from pydantic by calling `to_dict()` of signature
        if self.signature:
            _dict['signature'] = self.signature.to_dict()
        # override the default output from pydantic by calling `to_dict()` of carrier_return_window
        if self.carrier_return_window:
            _dict['carrier_return_window'] = self.carrier_return_window.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Images:
        """Create an instance of Images from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Images.parse_obj(obj)

        _obj = Images.parse_obj({
            "card": ImagesCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "carrier": ImagesCarrier.from_dict(obj.get("carrier")) if obj.get("carrier") is not None else None,
            "signature": ImagesSignature.from_dict(obj.get("signature")) if obj.get("signature") is not None else None,
            "carrier_return_window": ImagesCarrierReturnWindow.from_dict(obj.get("carrier_return_window")) if obj.get("carrier_return_window") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, constr, validator

class DigitalWalletTokenDevice(BaseModel):
    """
    DigitalWalletTokenDevice
    """
    device_type: Optional[StrictStr] = None
    device_lang_code: Optional[constr(strict=True, max_length=3, min_length=0)] = None
    device_id: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    device_number: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    device_name: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    device_location: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    device_ip_address: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    __properties = ["device_type", "device_lang_code", "device_id", "device_number", "device_name", "device_location", "device_ip_address"]

    @validator('device_type')
    def device_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNKNOWN', 'MOBILE_PHONE', 'WATCH', 'TABLET', 'MOBILE_PHONE_OR_TABLET', 'PERSONAL_COMPUTER'):
            raise ValueError("must be one of enum values ('UNKNOWN', 'MOBILE_PHONE', 'WATCH', 'TABLET', 'MOBILE_PHONE_OR_TABLET', 'PERSONAL_COMPUTER')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletTokenDevice:
        """Create an instance of DigitalWalletTokenDevice from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletTokenDevice:
        """Create an instance of DigitalWalletTokenDevice from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletTokenDevice.parse_obj(obj)

        _obj = DigitalWalletTokenDevice.parse_obj({
            "device_type": obj.get("device_type"),
            "device_lang_code": obj.get("device_lang_code"),
            "device_id": obj.get("device_id"),
            "device_number": obj.get("device_number"),
            "device_name": obj.get("device_name"),
            "device_location": obj.get("device_location"),
            "device_ip_address": obj.get("device_ip_address")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator
from marqeta_client.models.internal_funding_source import InternalFundingSource

class InternalGPAOrder(BaseModel):
    """
    InternalGPAOrder
    """
    tags: Optional[StrictStr] = None
    memo: Optional[StrictStr] = None
    token: StrictStr = ...
    amount: Union[StrictFloat, StrictInt] = ...
    currency: Optional[StrictStr] = None
    funding_source: Optional[InternalFundingSource] = Field(None, alias="fundingSource")
    original_order_id: Optional[StrictStr] = Field(None, alias="originalOrderId")
    order_type: Optional[StrictStr] = Field(None, alias="orderType")
    order_state: Optional[StrictStr] = Field(None, alias="orderState")
    response_code: Optional[StrictStr] = Field(None, alias="responseCode")
    response_memo: Optional[StrictStr] = Field(None, alias="responseMemo")
    created_time: Optional[datetime] = None
    last_modified_time: Optional[datetime] = None
    __properties = ["tags", "memo", "token", "amount", "currency", "fundingSource", "originalOrderId", "orderType", "orderState", "responseCode", "responseMemo", "created_time", "last_modified_time"]

    @validator('order_state')
    def order_state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PENDING', 'REVERSED', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR'):
            raise ValueError("must be one of enum values ('PENDING', 'REVERSED', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalGPAOrder:
        """Create an instance of InternalGPAOrder from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of funding_source
        if self.funding_source:
            _dict['fundingSource'] = self.funding_source.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalGPAOrder:
        """Create an instance of InternalGPAOrder from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalGPAOrder.parse_obj(obj)

        _obj = InternalGPAOrder.parse_obj({
            "tags": obj.get("tags"),
            "memo": obj.get("memo"),
            "token": obj.get("token"),
            "amount": obj.get("amount"),
            "currency": obj.get("currency"),
            "funding_source": InternalFundingSource.from_dict(obj.get("fundingSource")) if obj.get("fundingSource") is not None else None,
            "original_order_id": obj.get("originalOrderId"),
            "order_type": obj.get("orderType"),
            "order_state": obj.get("orderState"),
            "response_code": obj.get("responseCode"),
            "response_memo": obj.get("responseMemo"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictStr, confloat, conint, constr, validator
from marqeta_client.models.merchant_scope import MerchantScope
from marqeta_client.models.money_in_transaction import MoneyInTransaction
from marqeta_client.models.spend_control_association import SpendControlAssociation

class VelocityControlResponse(BaseModel):
    """
    VelocityControlResponse
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    name: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    association: Optional[SpendControlAssociation] = None
    merchant_scope: Optional[MerchantScope] = None
    usage_limit: Optional[conint(strict=True, ge=-1)] = None
    approvals_only: Optional[StrictBool] = None
    include_purchases: Optional[StrictBool] = None
    include_withdrawals: Optional[StrictBool] = None
    include_transfers: Optional[StrictBool] = None
    include_cashback: Optional[StrictBool] = None
    include_credits: Optional[StrictBool] = None
    money_in_transaction: Optional[MoneyInTransaction] = None
    currency_code: StrictStr = ...
    amount_limit: Union[confloat(ge=0, strict=True), conint(ge=0, strict=True)] = ...
    velocity_window: StrictStr = ...
    active: Optional[StrictBool] = None
    __properties = ["token", "name", "association", "merchant_scope", "usage_limit", "approvals_only", "include_purchases", "include_withdrawals", "include_transfers", "include_cashback", "include_credits", "money_in_transaction", "currency_code", "amount_limit", "velocity_window", "active"]

    @validator('velocity_window')
    def velocity_window_validate_enum(cls, v):
        if v not in ('DAY', 'WEEK', 'MONTH', 'LIFETIME', 'TRANSACTION'):
            raise ValueError("must be one of enum values ('DAY', 'WEEK', 'MONTH', 'LIFETIME', 'TRANSACTION')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VelocityControlResponse:
        """Create an instance of VelocityControlResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of association
        if self.association:
            _dict['association'] = self.association.to_dict()
        # override the default output from pydantic by calling `to_dict()` of merchant_scope
        if self.merchant_scope:
            _dict['merchant_scope'] = self.merchant_scope.to_dict()
        # override the default output from pydantic by calling `to_dict()` of money_in_transaction
        if self.money_in_transaction:
            _dict['money_in_transaction'] = self.money_in_transaction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VelocityControlResponse:
        """Create an instance of VelocityControlResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return VelocityControlResponse.parse_obj(obj)

        _obj = VelocityControlResponse.parse_obj({
            "token": obj.get("token"),
            "name": obj.get("name"),
            "association": SpendControlAssociation.from_dict(obj.get("association")) if obj.get("association") is not None else None,
            "merchant_scope": MerchantScope.from_dict(obj.get("merchant_scope")) if obj.get("merchant_scope") is not None else None,
            "usage_limit": obj.get("usage_limit"),
            "approvals_only": obj.get("approvals_only"),
            "include_purchases": obj.get("include_purchases"),
            "include_withdrawals": obj.get("include_withdrawals"),
            "include_transfers": obj.get("include_transfers"),
            "include_cashback": obj.get("include_cashback"),
            "include_credits": obj.get("include_credits"),
            "money_in_transaction": MoneyInTransaction.from_dict(obj.get("money_in_transaction")) if obj.get("money_in_transaction") is not None else None,
            "currency_code": obj.get("currency_code"),
            "amount_limit": obj.get("amount_limit"),
            "velocity_window": obj.get("velocity_window"),
            "active": obj.get("active")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, constr
from marqeta_client.models.billing_address import BillingAddress
from marqeta_client.models.original_credit import OriginalCredit
from marqeta_client.models.track1_data import Track1Data

class AdvancedAuthCardOptions(BaseModel):
    """
    AdvancedAuthCardOptions
    """
    cvv: Optional[constr(strict=True, max_length=3, min_length=0)] = None
    expiration: Optional[constr(strict=True, max_length=4, min_length=4)] = None
    billing_address: Optional[BillingAddress] = None
    track1_data: Optional[Track1Data] = None
    track2_data: Optional[Track1Data] = None
    original_credit: Optional[OriginalCredit] = None
    __properties = ["cvv", "expiration", "billing_address", "track1_data", "track2_data", "original_credit"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AdvancedAuthCardOptions:
        """Create an instance of AdvancedAuthCardOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of billing_address
        if self.billing_address:
            _dict['billing_address'] = self.billing_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of track1_data
        if self.track1_data:
            _dict['track1_data'] = self.track1_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of track2_data
        if self.track2_data:
            _dict['track2_data'] = self.track2_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_credit
        if self.original_credit:
            _dict['original_credit'] = self.original_credit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AdvancedAuthCardOptions:
        """Create an instance of AdvancedAuthCardOptions from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AdvancedAuthCardOptions.parse_obj(obj)

        _obj = AdvancedAuthCardOptions.parse_obj({
            "cvv": obj.get("cvv"),
            "expiration": obj.get("expiration"),
            "billing_address": BillingAddress.from_dict(obj.get("billing_address")) if obj.get("billing_address") is not None else None,
            "track1_data": Track1Data.from_dict(obj.get("track1_data")) if obj.get("track1_data") is not None else None,
            "track2_data": Track1Data.from_dict(obj.get("track2_data")) if obj.get("track2_data") is not None else None,
            "original_credit": OriginalCredit.from_dict(obj.get("original_credit")) if obj.get("original_credit") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, constr

class AddressResponseModel(BaseModel):
    """
    AddressResponseModel
    """
    address1: Optional[constr(strict=True, max_length=35, min_length=0)] = None
    address2: Optional[constr(strict=True, max_length=35, min_length=0)] = None
    city: Optional[constr(strict=True, max_length=35, min_length=0)] = None
    state: Optional[constr(strict=True, max_length=35, min_length=0)] = None
    zip: Optional[constr(strict=True, max_length=20, min_length=0)] = None
    postal_code: Optional[constr(strict=True, max_length=20, min_length=0)] = None
    country: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    __properties = ["address1", "address2", "city", "state", "zip", "postal_code", "country"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AddressResponseModel:
        """Create an instance of AddressResponseModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AddressResponseModel:
        """Create an instance of AddressResponseModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AddressResponseModel.parse_obj(obj)

        _obj = AddressResponseModel.parse_obj({
            "address1": obj.get("address1"),
            "address2": obj.get("address2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "zip": obj.get("zip"),
            "postal_code": obj.get("postal_code"),
            "country": obj.get("country")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conint, constr

class GatewayProgramFundingSourceRequest(BaseModel):
    """
    GatewayProgramFundingSourceRequest
    """
    name: constr(strict=True, max_length=50, min_length=1) = ...
    url: constr(strict=True, max_length=250, min_length=0) = ...
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    active: Optional[StrictBool] = None
    basic_auth_username: constr(strict=True, max_length=50, min_length=1) = ...
    basic_auth_password: constr(strict=True, max_length=100, min_length=20) = ...
    timeout_millis: Optional[conint(strict=True, le=7000, ge=1000)] = Field(None, description="Total timeout in milliseconds for gateway processing")
    custom_header: Optional[Dict[str, StrictStr]] = Field(None, description="Custom headers")
    use_mtls: Optional[StrictBool] = Field(False, description="Use MTLS for funding request")
    __properties = ["name", "url", "token", "active", "basic_auth_username", "basic_auth_password", "timeout_millis", "custom_header", "use_mtls"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GatewayProgramFundingSourceRequest:
        """Create an instance of GatewayProgramFundingSourceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GatewayProgramFundingSourceRequest:
        """Create an instance of GatewayProgramFundingSourceRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GatewayProgramFundingSourceRequest.parse_obj(obj)

        _obj = GatewayProgramFundingSourceRequest.parse_obj({
            "name": obj.get("name"),
            "url": obj.get("url"),
            "token": obj.get("token"),
            "active": obj.get("active"),
            "basic_auth_username": obj.get("basic_auth_username"),
            "basic_auth_password": obj.get("basic_auth_password"),
            "timeout_millis": obj.get("timeout_millis"),
            "custom_header": obj.get("custom_header"),
            "use_mtls": obj.get("use_mtls") if obj.get("use_mtls") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr

class ACHReturn(BaseModel):
    """
    ACHReturn
    """
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    var_date: Optional[datetime] = Field(None, alias="date")
    date_initiated: Optional[datetime] = Field(None, alias="dateInitiated")
    order_id: Optional[StrictStr] = Field(None, alias="orderId")
    reason_code: Optional[StrictStr] = Field(None, alias="reasonCode")
    direct_deposit: Optional[StrictBool] = Field(None, alias="directDeposit")
    ach_type: Optional[StrictStr] = Field(None, alias="achType")
    __properties = ["amount", "date", "dateInitiated", "orderId", "reasonCode", "directDeposit", "achType"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ACHReturn:
        """Create an instance of ACHReturn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ACHReturn:
        """Create an instance of ACHReturn from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ACHReturn.parse_obj(obj)

        _obj = ACHReturn.parse_obj({
            "amount": obj.get("amount"),
            "var_date": obj.get("date"),
            "date_initiated": obj.get("dateInitiated"),
            "order_id": obj.get("orderId"),
            "reason_code": obj.get("reasonCode"),
            "direct_deposit": obj.get("directDeposit"),
            "ach_type": obj.get("achType")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist

class CardholderAuthenticationData(BaseModel):
    """
    CardholderAuthenticationData
    """
    electronic_commerce_indicator: Optional[StrictStr] = None
    verification_result: Optional[StrictStr] = None
    verification_value_created_by: Optional[StrictStr] = None
    acquirer_exemption: Optional[conlist(StrictStr)] = None
    three_ds_message_version: Optional[StrictStr] = None
    authentication_method: Optional[StrictStr] = None
    authentication_status: Optional[StrictStr] = None
    issuer_exemption: Optional[StrictStr] = None
    __properties = ["electronic_commerce_indicator", "verification_result", "verification_value_created_by", "acquirer_exemption", "three_ds_message_version", "authentication_method", "authentication_status", "issuer_exemption"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardholderAuthenticationData:
        """Create an instance of CardholderAuthenticationData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardholderAuthenticationData:
        """Create an instance of CardholderAuthenticationData from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardholderAuthenticationData.parse_obj(obj)

        _obj = CardholderAuthenticationData.parse_obj({
            "electronic_commerce_indicator": obj.get("electronic_commerce_indicator"),
            "verification_result": obj.get("verification_result"),
            "verification_value_created_by": obj.get("verification_value_created_by"),
            "acquirer_exemption": obj.get("acquirer_exemption"),
            "three_ds_message_version": obj.get("three_ds_message_version"),
            "authentication_method": obj.get("authentication_method"),
            "authentication_status": obj.get("authentication_status"),
            "issuer_exemption": obj.get("issuer_exemption")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, validator

class ProgramReserveTransactionResponse(BaseModel):
    """
    ProgramReserveTransactionResponse
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    token: Optional[StrictStr] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    currency_code: Optional[StrictStr] = None
    memo: Optional[StrictStr] = None
    tags: Optional[StrictStr] = None
    transaction_token: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    is_collateral: Optional[StrictBool] = None
    __properties = ["created_time", "last_modified_time", "token", "amount", "currency_code", "memo", "tags", "transaction_token", "type", "state", "is_collateral"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('CREDIT', 'DEBIT', 'PENDING_CREDIT', 'PENDING_DEBIT'):
            raise ValueError("must be one of enum values ('CREDIT', 'DEBIT', 'PENDING_CREDIT', 'PENDING_DEBIT')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PENDING', 'COMPLETE'):
            raise ValueError("must be one of enum values ('PENDING', 'COMPLETE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProgramReserveTransactionResponse:
        """Create an instance of ProgramReserveTransactionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProgramReserveTransactionResponse:
        """Create an instance of ProgramReserveTransactionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ProgramReserveTransactionResponse.parse_obj(obj)

        _obj = ProgramReserveTransactionResponse.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "token": obj.get("token"),
            "amount": obj.get("amount"),
            "currency_code": obj.get("currency_code"),
            "memo": obj.get("memo"),
            "tags": obj.get("tags"),
            "transaction_token": obj.get("transaction_token"),
            "type": obj.get("type"),
            "state": obj.get("state"),
            "is_collateral": obj.get("is_collateral")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr
from marqeta_client.models.internal_card import InternalCard
from marqeta_client.models.transaction import Transaction

class InternalUserTransactionRequest(BaseModel):
    """
    InternalUserTransactionRequest
    """
    token: constr(strict=True, max_length=36, min_length=1) = ...
    card: InternalCard = ...
    digital_wallet_token: Optional[StrictStr] = Field(None, alias="digitalWalletToken")
    transaction: Optional[Transaction] = None
    __properties = ["token", "card", "digitalWalletToken", "transaction"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalUserTransactionRequest:
        """Create an instance of InternalUserTransactionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalUserTransactionRequest:
        """Create an instance of InternalUserTransactionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalUserTransactionRequest.parse_obj(obj)

        _obj = InternalUserTransactionRequest.parse_obj({
            "token": obj.get("token"),
            "card": InternalCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "digital_wallet_token": obj.get("digitalWalletToken"),
            "transaction": Transaction.from_dict(obj.get("transaction")) if obj.get("transaction") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr
from marqeta_client.models.activation_actions import ActivationActions
from marqeta_client.models.card_fulfillment_request import CardFulfillmentRequest
from marqeta_client.models.expiration_offset import ExpirationOffset

class CardRequest(BaseModel):
    """
    CardRequest
    """
    card_product_token: constr(strict=True, max_length=36, min_length=1) = ...
    expedite: Optional[StrictBool] = False
    metadata: Optional[Dict[str, StrictStr]] = None
    expiration_offset: Optional[ExpirationOffset] = None
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    user_token: constr(strict=True, max_length=36, min_length=1) = ...
    fulfillment: Optional[CardFulfillmentRequest] = None
    reissue_pan_from_card_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    new_pan_from_card_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    translate_pin_from_card_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    activation_actions: Optional[ActivationActions] = None
    bulk_issuance_token: Optional[StrictStr] = None
    __properties = ["card_product_token", "expedite", "metadata", "expiration_offset", "token", "user_token", "fulfillment", "reissue_pan_from_card_token", "new_pan_from_card_token", "translate_pin_from_card_token", "activation_actions", "bulk_issuance_token"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardRequest:
        """Create an instance of CardRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of expiration_offset
        if self.expiration_offset:
            _dict['expiration_offset'] = self.expiration_offset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fulfillment
        if self.fulfillment:
            _dict['fulfillment'] = self.fulfillment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of activation_actions
        if self.activation_actions:
            _dict['activation_actions'] = self.activation_actions.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardRequest:
        """Create an instance of CardRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardRequest.parse_obj(obj)

        _obj = CardRequest.parse_obj({
            "card_product_token": obj.get("card_product_token"),
            "expedite": obj.get("expedite") if obj.get("expedite") is not None else False,
            "metadata": obj.get("metadata"),
            "expiration_offset": ExpirationOffset.from_dict(obj.get("expiration_offset")) if obj.get("expiration_offset") is not None else None,
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "fulfillment": CardFulfillmentRequest.from_dict(obj.get("fulfillment")) if obj.get("fulfillment") is not None else None,
            "reissue_pan_from_card_token": obj.get("reissue_pan_from_card_token"),
            "new_pan_from_card_token": obj.get("new_pan_from_card_token"),
            "translate_pin_from_card_token": obj.get("translate_pin_from_card_token"),
            "activation_actions": ActivationActions.from_dict(obj.get("activation_actions")) if obj.get("activation_actions") is not None else None,
            "bulk_issuance_token": obj.get("bulk_issuance_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator
from marqeta_client.models.carrier import Carrier
from marqeta_client.models.images import Images
from marqeta_client.models.text import Text

class CardPersonalization(BaseModel):
    """
    CardPersonalization
    """
    text: Text = ...
    images: Optional[Images] = None
    carrier: Optional[Carrier] = None
    perso_type: Optional[StrictStr] = None
    __properties = ["text", "images", "carrier", "perso_type"]

    @validator('perso_type')
    def perso_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('EMBOSS', 'LASER', 'FLAT'):
            raise ValueError("must be one of enum values ('EMBOSS', 'LASER', 'FLAT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardPersonalization:
        """Create an instance of CardPersonalization from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of text
        if self.text:
            _dict['text'] = self.text.to_dict()
        # override the default output from pydantic by calling `to_dict()` of images
        if self.images:
            _dict['images'] = self.images.to_dict()
        # override the default output from pydantic by calling `to_dict()` of carrier
        if self.carrier:
            _dict['carrier'] = self.carrier.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardPersonalization:
        """Create an instance of CardPersonalization from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardPersonalization.parse_obj(obj)

        _obj = CardPersonalization.parse_obj({
            "text": Text.from_dict(obj.get("text")) if obj.get("text") is not None else None,
            "images": Images.from_dict(obj.get("images")) if obj.get("images") is not None else None,
            "carrier": Carrier.from_dict(obj.get("carrier")) if obj.get("carrier") is not None else None,
            "perso_type": obj.get("perso_type")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr

class MsaBalances(BaseModel):
    """
    MsaBalances
    """
    currency_code: StrictStr = ...
    ledger_balance: Union[StrictFloat, StrictInt] = ...
    available_balance: Union[StrictFloat, StrictInt] = ...
    credit_balance: Union[StrictFloat, StrictInt] = ...
    cached_balance: Union[StrictFloat, StrictInt] = ...
    pending_credits: Union[StrictFloat, StrictInt] = ...
    impacted_amount: Optional[Union[StrictFloat, StrictInt]] = None
    balances: Dict[str, MsaBalances] = ...
    last_updated_time: datetime = ...
    __properties = ["currency_code", "ledger_balance", "available_balance", "credit_balance", "cached_balance", "pending_credits", "impacted_amount", "balances", "last_updated_time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MsaBalances:
        """Create an instance of MsaBalances from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in balances (dict)
        _field_dict = {}
        if self.balances:
            for _key in self.balances:
                if self.balances[_key]:
                    _field_dict[_key] = self.balances[_key].to_dict()
            _dict['balances'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MsaBalances:
        """Create an instance of MsaBalances from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MsaBalances.parse_obj(obj)

        _obj = MsaBalances.parse_obj({
            "currency_code": obj.get("currency_code"),
            "ledger_balance": obj.get("ledger_balance"),
            "available_balance": obj.get("available_balance"),
            "credit_balance": obj.get("credit_balance"),
            "cached_balance": obj.get("cached_balance"),
            "pending_credits": obj.get("pending_credits"),
            "impacted_amount": obj.get("impacted_amount"),
            "balances": dict(
                (_k, MsaBalances.from_dict(_v))
                for _k, _v in obj.get("balances").items()
            )
            if obj.get("balances") is not None
            else None,
            "last_updated_time": obj.get("last_updated_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, constr, validator

class OriginalCreditSenderData(BaseModel):
    """
    OriginalCreditSenderData
    """
    funding_source: StrictStr = ...
    sender_account_type: Optional[StrictStr] = None
    sender_name: Optional[StrictStr] = None
    sender_reference_number: Optional[StrictStr] = None
    sender_account_number: Optional[StrictStr] = None
    sender_address: Optional[StrictStr] = None
    sender_city: Optional[StrictStr] = None
    sender_state: Optional[StrictStr] = None
    sender_country: Optional[StrictStr] = None
    unique_transaction_reference_number: Optional[constr(strict=True, max_length=17, min_length=1)] = None
    transaction_purpose: Optional[StrictStr] = None
    visa_transaction_purpose: Optional[StrictStr] = None
    deferred_hold_by: Optional[StrictStr] = None
    __properties = ["funding_source", "sender_account_type", "sender_name", "sender_reference_number", "sender_account_number", "sender_address", "sender_city", "sender_state", "sender_country", "unique_transaction_reference_number", "transaction_purpose", "visa_transaction_purpose", "deferred_hold_by"]

    @validator('funding_source')
    def funding_source_validate_enum(cls, v):
        if v not in ('credit', 'debit', 'prepaid', 'deposit_account', 'cash', 'mobile_money_payment', 'non_visa_credit'):
            raise ValueError("must be one of enum values ('credit', 'debit', 'prepaid', 'deposit_account', 'cash', 'mobile_money_payment', 'non_visa_credit')")
        return v

    @validator('sender_account_type')
    def sender_account_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('other', 'rtn_bank_account', 'iban', 'card_account', 'email', 'phone_number', 'bank_account_number_and_identification_code', 'wallet_id', 'social_network_id'):
            raise ValueError("must be one of enum values ('other', 'rtn_bank_account', 'iban', 'card_account', 'email', 'phone_number', 'bank_account_number_and_identification_code', 'wallet_id', 'social_network_id')")
        return v

    @validator('transaction_purpose')
    def transaction_purpose_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('family_support', 'labor_transfers', 'travel', 'education', 'medical_treatment', 'emergency_need', 'savings', 'gifts', 'other', 'salary', 'lending', 'crypto_currency'):
            raise ValueError("must be one of enum values ('family_support', 'labor_transfers', 'travel', 'education', 'medical_treatment', 'emergency_need', 'savings', 'gifts', 'other', 'salary', 'lending', 'crypto_currency')")
        return v

    @validator('deferred_hold_by')
    def deferred_hold_by_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('absent', 'visa', 'originator'):
            raise ValueError("must be one of enum values ('absent', 'visa', 'originator')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OriginalCreditSenderData:
        """Create an instance of OriginalCreditSenderData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OriginalCreditSenderData:
        """Create an instance of OriginalCreditSenderData from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return OriginalCreditSenderData.parse_obj(obj)

        _obj = OriginalCreditSenderData.parse_obj({
            "funding_source": obj.get("funding_source"),
            "sender_account_type": obj.get("sender_account_type"),
            "sender_name": obj.get("sender_name"),
            "sender_reference_number": obj.get("sender_reference_number"),
            "sender_account_number": obj.get("sender_account_number"),
            "sender_address": obj.get("sender_address"),
            "sender_city": obj.get("sender_city"),
            "sender_state": obj.get("sender_state"),
            "sender_country": obj.get("sender_country"),
            "unique_transaction_reference_number": obj.get("unique_transaction_reference_number"),
            "transaction_purpose": obj.get("transaction_purpose"),
            "visa_transaction_purpose": obj.get("visa_transaction_purpose"),
            "deferred_hold_by": obj.get("deferred_hold_by")
        })
        return _obj

